# InAccel Coral API

[![C (Core)](https://img.shields.io/static/v1?logo=c&color=a8b9cc&label=C%20(Core)&message=2.2&style=for-the-badge)](src/main/c)
[![C++](https://img.shields.io/static/v1?logo=c%2b%2b&color=00599c&label=C%2B%2B&message=2.2.0&style=for-the-badge)](src/main/cpp)
[![Java](https://img.shields.io/static/v1?logo=openjdk&color=ffffff&label=Java&message=2.2.0&style=for-the-badge)](src/main/java)
[![Python](https://img.shields.io/static/v1?logo=python&color=3776ab&label=Python&message=2.2.0&style=for-the-badge)](src/main/python)
